==> Quincy2005ProjectV1.2.zip: Quincy2005ProjectV1.2/beautifier.h <==
#if !defined(AFX_BEAUTIFER_H__1C115531_2B12_4F55_BA60_EBD2602159AC__INCLUDED_)
#define AFX_BEAUTIFER_H__1C115531_2B12_4F55_BA60_EBD2602159AC__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// Beautifer.h : header file
//
#include <vector>

/////////////////////////////////////////////////////////////////////////////
// CBeautifier dialog

class CBeautifier : public CDialog
{
	CFont* font;
	std::vector<std::string> beautifiedtext;
	static CBeautifier* pBeautifier;
	ConsoleApp* m_pConsoleApp;
	static void Collect(DWORD bufct);
	void CollectSourceLines(DWORD bufct);
	void NotifyTermination();
	static void Notify();

// Construction
public:
	CBeautifier(CWnd* pParent = NULL);   // standard constructor
	~CBeautifier();
// Dialog Data
	//{{AFX_DATA(CBeautifier)
	enum { IDD = IDD_BEAUTIFIER };
	CButton	m_TestStyle;
	CEdit	m_CmdLineEdit;
	CEdit	m_samplecode;
	int		m_style;
	CString	m_Cmdline;
	//}}AFX_DATA


// Overrides
	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CBeautifier)
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
	//}}AFX_VIRTUAL

// Implementation
protected:

	// Generated message map functions
	//{{AFX_MSG(CBeautifier)
	afx_msg void OnStyle();
	virtual BOOL OnInitDialog();
	afx_msg void OnHelp();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ will insert additional declarations immediately before the previous line.

#endif // !defined(AFX_BEAUTIFER_H__1C115531_2B12_4F55_BA60_EBD2602159AC__INCLUDED_)

==> Quincy2005ProjectV1.3.zip: Quincy2005ProjectV1.3/beautifier.h <==
#if !defined(AFX_BEAUTIFER_H__1C115531_2B12_4F55_BA60_EBD2602159AC__INCLUDED_)
#define AFX_BEAUTIFER_H__1C115531_2B12_4F55_BA60_EBD2602159AC__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// Beautifer.h : header file
//
#include <vector>

/////////////////////////////////////////////////////////////////////////////
// CBeautifier dialog

class CBeautifier : public CDialog
{
	CFont* font;
	std::vector<std::string> beautifiedtext;
	static CBeautifier* pBeautifier;
	ConsoleApp* m_pConsoleApp;
	static void Collect(DWORD bufct);
	void CollectSourceLines(DWORD bufct);
	void NotifyTermination();
	static void Notify();

// Construction
public:
	CBeautifier(CWnd* pParent = NULL);   // standard constructor
	~CBeautifier();
// Dialog Data
	//{{AFX_DATA(CBeautifier)
	enum { IDD = IDD_BEAUTIFIER };
	CButton	m_TestStyle;
	CEdit	m_CmdLineEdit;
	CEdit	m_samplecode;
	int		m_style;
	CString	m_Cmdline;
	//}}AFX_DATA


// Overrides
	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CBeautifier)
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
	//}}AFX_VIRTUAL

// Implementation
protected:

	// Generated message map functions
	//{{AFX_MSG(CBeautifier)
//	afx_msg void OnStyle();
	virtual BOOL OnInitDialog();
	afx_msg void OnHelp();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
public:
	afx_msg void OnBnClickedStyle1();
	afx_msg void OnBnClickedStyle2();
	afx_msg void OnBnClickedStyle3();
	afx_msg void OnBnClickedStyle4();
	afx_msg void OnBnClickedStyle5();
	void OnStyle();
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ will insert additional declarations immediately before the previous line.

#endif // !defined(AFX_BEAUTIFER_H__1C115531_2B12_4F55_BA60_EBD2602159AC__INCLUDED_)
